@@ -52,10 +52,12 @@ namespace urcl
  */
 struct UrDriverConfiguration
 {
-  std::string robot_ip;            //!< IP-address under which the robot is reachable.
-  std::string script_file;         //!< URScript file that should be sent to the robot.
-  std::string output_recipe_file;  //!< Filename where the output recipe is stored in.
-  std::string input_recipe_file;   //!< Filename where the input recipe is stored in.
+  std::string robot_ip;                    //!< IP-address under which the robot is reachable.
+  std::string script_file;                 //!< URScript file that should be sent to the robot.
+  std::string output_recipe_file;          //!< Filename where the output recipe is stored in.
+  std::string input_recipe_file;           //!< Filename where the input recipe is stored in.
+  std::vector<std::string> output_recipe;  //!< Vector with the output recipe fields.
+  std::vector<std::string> input_recipe;   //!< Vector with the input recipe fields.
 
   /*!
    * \brief Function handle to a callback on program state changes.
@@ -63,7 +65,7 @@ struct UrDriverConfiguration
    * For this to work, the URScript program will have to send keepalive signals to the \p
    * reverse_port.
    */
-  std::function<void(bool)> handle_program_state;
+  std::function<void(bool)> handle_program_state = nullptr;
   bool headless_mode;  //!< Parameter to control if the driver should be started in headless mode.
 
   std::unique_ptr<ToolCommSetup> tool_comm_setup = nullptr;  //!< Configuration for using the tool communication.
@@ -594,6 +596,17 @@ public:
    */
   bool setPayload(const float mass, const vector3d_t& cog);
 
+  /*!
+   * \brief Set the gravity vector. Note: It requires the external control script to be running or
+   * the robot to be in headless mode.
+   *
+   * \param gravity Gravity, a vector [x, y, z] specifying the gravity vector (pointing towards
+   * the Earth's center) given in the robot's base frame
+   *
+   * \returns True on successful write.
+   */
+  bool setGravity(const vector3d_t& gravity);
+
   /*!
    * \brief Set the tool voltage. Note: It requires the external control script to be running or the robot to be in
    * headless mode.
@@ -837,6 +850,13 @@ public:
    */
   std::vector<std::string> getRTDEOutputRecipe();
 
+  /*!
+   * \brief Getter for the RTDE input recipe used in the RTDE client.
+   *
+   * \returns The used RTDE input recipe
+   */
+  std::vector<std::string> getRTDEInputRecipe();
+
   /*!
    * \brief Set the Keepalive count. This will set the number of allowed timeout reads on the robot.
    *
@@ -987,6 +1007,7 @@ public:
 private:
   void init(const UrDriverConfiguration& config);
 
+  void setupRTDEClient(const UrDriverConfiguration& config);
   void initRTDE();
   void setupReverseInterface(const uint32_t reverse_port);
 
@@ -1023,4 +1044,4 @@ private:
   VersionInformation robot_version_;
 };
 }  // namespace urcl
-#endif  // ifndef UR_CLIENT_LIBRARY_UR_UR_DRIVER_H_INCLUDED
+#endif  // ifndef UR_CLIENT_LIBRARY_UR_UR_DRIVER_H_INCLUDED
\ No newline at end of file
